## Summary

<!-- Describe what this PR does and why. -->

## Changes

- [ ] Added / modified feature: ...
- [ ] Tests added / updated
- [ ] Docs updated (`docs/`)
- [ ] `docs/changelog.md` updated

## Related Issues

Closes #

## Checklist

- [ ] `make test` passes locally (all tests green)
- [ ] No credentials or secrets in code
- [ ] Type hints added on public functions
- [ ] `LOG_LEVEL=DEBUG` produces useful output
